# Cryptology
This is a package which decrypt/encrypts text using a few different methods.

## Installation
Run the following to install:

```python
pip3 instal cryptology
```

## Usage
```python
from cryptology import atbash_decrypt

# Generate decryption
string=atbash_decrypt(cipher_text="GSRHRHMLGEVIBHVXIVGZGZOO")

print(string)
```

